@@ -17,7 +17,7 @@
          w <- fo$stats$weights
          fl <- fo$schmid$sl
          Phi <- NULL
-         fl <- fl[,1:(dim(fl)[2]-3)]
+         fl <- fl[,1:(dim(fl)[2]-4)]    #just the loadings
          nfactors <- dim(fl)[2]
          fe <- t(t(w) %*% Roe)
          foblique <- fo$schmid$oblique
@@ -83,7 +83,7 @@ function(r,nfactors=1,ov=NULL,ev=NULL,n.obs = NA, np.obs=NULL,correct=TRUE,rotat
        mixed = {r <- mixedCor(r,use=use,correct=cor.correct)$rho}
        )
        
- if(omega) {fo <- omega(r[ov,ov],nfactors=nfactors,rotate=rotate,SMC=SMC,warnings=warnings,fm=fm,alpha=alpha,...)} else {
+ if(omega) {fo <- omega(r[ov,ov],nfactors=nfactors,rotate=rotate,SMC=SMC,warnings=warnings,fm=fm,alpha=alpha,smooth=smooth,...)} else {
        fo <- fa(r[ov,ov],nfactors=nfactors,rotate=rotate,SMC=SMC,warnings=warnings,fm=fm,cor=cor,alpha=alpha, missing=missing,impute="mean", smooth=smooth,...)}
      
            
