@@ -1,6 +1,6 @@
 #added the coarse option (defaulting to TRUE)  8/25/23
 #added the dof parameter (passed from cfa)   12/1/25
-
+#Fixed the statistics to just work on lower off diagonal values   1/15/26
 "factor.stats" <- 
 function(r=NULL,f,phi=NULL,n.obs=NA,np.obs=NULL,alpha=.1,fm=NULL,smooth=TRUE, coarse=TRUE, dof=NULL) {
    fa.stats(r=r,f=f,phi=phi,n.obs=n.obs,np.obs=np.obs,alpha=alpha,fm=fm,smooth=smooth,coarse=coarse, dof=dof)}
@@ -30,8 +30,8 @@ conf.level <- alpha
  nfactors <- dim(f)[2]  # number of factors
  if(is.null(phi)) {model <- f %*%  t(f)} else {model <- f %*% phi %*% t(f)}
 
-    residual<- r - model
-  
+    residual<- r - model  #but this is twice the lower off diagonal  
+    #all of these need to be adjusted for the symmetry/redundancy
     r2 <- sum(r*r)
     rstar2 <- sum(residual*residual)
     result <- list(residual = residual)
@@ -43,8 +43,8 @@ conf.level <- alpha
    # r2.off <- sum(r2.off^2)
     r2.off <- r2 - tr(r)
     diag(residual) <- 0
-    if(is.null(np.obs))  {rstar.off <- sum(residual^2)
-                          result$ENull <- r2.off * n.obs  #the empirical null model
+    if(is.null(np.obs))  {rstar.off <- sum(residual^2)/2   #fixed 1/15/26 to divide by 2
+                          result$ENull <- r2.off * n.obs /2 #the empirical null model
                           result$chi <- rstar.off * n.obs  #this is the empirical chi square
                           result$rms <- sqrt(rstar.off/(n*(n-1)))  #this is the empirical rmsea
                         
@@ -61,11 +61,14 @@ conf.level <- alpha
                            rstar.off <- sum(residual^2 * np.obs)  #weight the residuals by their sample size
                           r2.off <-(r*r * np.obs)   #weight the original by sample size
                           r2.off <- sum(r2.off) -tr(r2.off) 
-                          result$chi <- rstar.off  #this is the sample size weighted chi square
+                          #all of these need to be fixed
+                          # fixed 1/15/26 
+                          result$chi <- rstar.off /2 #this is the sample size weighted chi square 
+                           
                           result$nh <- harmonic.mean(as.vector(np.obs)) #this is the sample weighted cell size
                           result$rms <- sqrt(rstar.off/(result$nh*n*(n-1))) #this is the sample size weighted square root average squared residual
                         if (result$dof > 0) {result$EPVAL <- pchisq(result$chi, result$dof, lower.tail = FALSE)
-                                              result$crms <- sqrt(rstar.off/(2*result$nh*result$dof) )
+                                              result$crms <- sqrt(rstar.off/(2*result$nh*result$dof) )  #ok
                                               result$EBIC <- result$chi - result$dof * log(result$nh) 
                                               result$ESABIC <- result$chi - result$dof * log((result$nh+2)/24) } else {   #added 2/28/2014 
                                               result$EPVAL <- NA
@@ -267,16 +270,22 @@ conf.level <- alpha
        r <- ev$vectors %*% diag(ev$values) %*% t(ev$vectors)
        diag(r)  <- 1
     # w <- try(solve(r,f) ,silent=TRUE) 
-      w <- Pinv(r)%*% r  #use the Pseudo inverse  #these are the factor weights
+      w <- Pinv(r)%*% f  #use the Pseudo inverse  #these are the factor weights
 
      if(inherits(w,"try-error")) {warning("In factor.stats, the correlation matrix is singular, and we could not calculate the beta weights for factor score estimates")
      w <- diag(1,dim(r)[1])
      }   #these are the beta weights 
     }}
-      R2 <- diag(t(w) %*% f)   #but, we actually already found this in factor scores -- these are the Thurstone values
-      if(is.null(fm)) {
+   
+     # R2 <- diag(t(w) %*% f)   # but, we actually already found this in factor scores -- these are the Thurstone values
+      C <- t(w)%*% r %*% w  #see Grice 13
+      sd.in <- 1/sqrt(diag(C))
+      
+      R2 <- diag(t(w) %*% f) * sd.in #correction added 12/20/25
+                            R2[abs(R2) > 1] <- .999  # a fudge for CFA 
+       if(is.null(fm)) {
      if(prod(R2,na.rm=TRUE) < 0 ) {message("In factor.stats: The factor scoring weights matrix is probably singular -- Factor score estimate results are likely incorrect.\n Try a different factor score estimation method\n")
-                      R2[abs(R2) > 1] <- NA
+                      R2[abs(R2) > 1] <- 1.00
                       R2[R2 <= 0] <- NA
                      }
      if ((max(R2,na.rm=TRUE) > (1 + .Machine$double.eps)) ) {warning("The estimated weights for the factor scores are probably incorrect.  Try a different factor score estimation method.")}
@@ -286,7 +295,7 @@ conf.level <- alpha
     #  H <- t(f)  %*% solve(r) % f #just the same as R2 of factor scores with factors if f is the Structure coeffient
       r.scores <- cov2cor(t(w) %*% r %*% w) 
       result$r.scores <- r.scores 
-   	  result$R2 <- R2   #this is the multiple R2 of the scores with the factors
+   	  result$R2 <- R2   #this is the multiple R2 of the scores with the factors  
    	 
    	 
    	  
