@@ -30,7 +30,9 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, covar=FALSE,s
        cor = {if(!is.null(weight))  {r <- cor.wt(r,w=weight)$r} else  {
                                      r <- cor(r,use=use)}
                                      },
-       cov = {r <- cov(r,use=use) 
+       cov = {if(!is.null(weight))  {r <- cor.wt(r,w=weight,cor=FALSE)$r} else  {
+                                     r <- cov(r,use=use)}
+                                      
               covar <- TRUE},
        wtd = { r <- cor.wt(r,w=weight)$r},
        spearman = {r <- cor(r,use=use,method="spearman")},
@@ -238,7 +240,7 @@ switch(rotate,  #The orthogonal cases  for GPArotation + ones developed for psyc
     result$communality <- communalities
     result$uniquenesses <- uniquenesses
     result$complexity <- stats$complexity
-    #result$stats <- stats
+    result$stats <- stats
     result$valid <- stats$valid  #added 12/12/22 
     result$chi <- stats$chi
     result$EPVAL <- stats$EPVAL
@@ -259,6 +261,7 @@ switch(rotate,  #The orthogonal cases  for GPArotation + ones developed for psyc
     result$r.scores <-  stats$r.scores
      result$rot.mat <- rot.mat
      result$Vaccounted <-varex
+     result$r <- r
     if(!is.null(Phi) && oblique.scores) {
                        result$Structure <- loadings %*% Phi} else {result$Structure <- loadings
                        }
