@@ -77,7 +77,7 @@ if(any( !(select %in% colnames(items)) )) {
 
    items <- as.matrix(items)
     
-    response.freq <- response.frequencies(items)
+    response.freq <- responseFrequency(items)
     item.var <- apply(items,2,sd,na.rm=TRUE)
        bad <- which((item.var==0)|is.na(item.var))   #is this a good idea? 
        #bad <- which(is.na(item.var)) 
